@@ -12,9 +12,3 @@ def lint(session):
     session.install(".[lint]")
     session.run("ruff", "check", ".")
     session.run("black", "--check", ".")
-
-
-@nox.session
-def build(session):
-    session.install("flit")
-    session.run("flit", "build")
