@@ -1,4 +1,3 @@
-import configparser
 import os
 import pathlib
 import subprocess
@@ -38,10 +37,15 @@ def micro_venv(tmp_path_factory):
 
 
 def pyvenvcfg(venv_path):
-    config_text = (venv_path / "pyvenv.cfg").read_text(encoding="utf-8")
-    config = configparser.ConfigParser()
-    config.read_string("\n".join(["[_]", config_text]))
-    return config["_"]
+    config = {}
+    with open(venv_path / "pyvenv.cfg", "r", encoding="utf-8") as file:
+        for line in file:
+            if "=" in line:
+                # This is how `site` reads a `pyvenv.cfg`, so it's about as
+                # official as we can get.
+                key, _, value = line.partition("=")
+                config[key.strip().lower()] = value.strip()
+    return config
 
 
 def test_structure(full_venv, micro_venv):
@@ -51,7 +55,7 @@ def test_structure(full_venv, micro_venv):
         micro_root = micro_venv / relative_root
         for dirname in dirnames:
             micro_dir = micro_root / dirname
-            micro_dir.is_dir()
+            assert micro_dir.is_dir()
 
         for filename in filenames:
             # Don't care about activation scripts.
@@ -75,6 +79,8 @@ def test_lib64(full_venv, micro_venv):
         assert micro_lib64.exists()
         assert micro_lib64.is_symlink()
         assert micro_lib64.resolve() == (micro_venv / "lib")
+        # pathlib.Path.readlink() was added in Python 3.9.
+        assert os.readlink(micro_lib64) == "lib"
 
 
 @pytest.mark.parametrize(
@@ -114,13 +120,13 @@ def test_pyvenvcfg_executable(base_executable, full_venv, micro_venv):
     assert micro_config["executable"] == executable_path
 
 
-def test_pyvenvfg_command(executable, micro_venv):
+def test_pyvenvcfg_command(executable, micro_venv):
     config = pyvenvcfg(micro_venv)
     script_path = pathlib.Path(microvenv.__file__).resolve()
     assert config["command"] == f"{executable} {script_path} {micro_venv.resolve()}"
 
 
-def test_pyvencfg_command_relative(executable, monkeypatch, tmp_path):
+def test_pyvenvcfg_command_relative(executable, monkeypatch, tmp_path):
     monkeypatch.chdir(tmp_path)
     venv_path = tmp_path / "venv"
     microvenv.create(pathlib.Path(venv_path.name))
@@ -134,5 +140,10 @@ def test_code_size(executable, monkeypatch, tmp_path):
     with open(microvenv.__file__, "r", encoding="utf-8") as file:
         source = file.read()
     monkeypatch.chdir(tmp_path)
+    env_path = pathlib.Path(".venv")
     subprocess.check_call([os.fsdecode(executable), "-c", source])
-    assert pathlib.Path(".venv").is_dir()
+
+    assert env_path.is_dir()
+    command = pyvenvcfg(env_path)["command"]
+    assert command.startswith(sys.executable)
+    assert " -c " in command
